@@ -13,8 +13,6 @@ import html
 import platform
 from yattag import Doc
 import re
-import seaborn as sns
-import scipy.stats as stats
 
 # This is a Windows workaround for a bug in wkhtmltopdf:
 # https://github.com/wkhtmltopdf/wkhtmltopdf/issues/3081
